#
# spec file for package intel-cmt-cat
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2016 Intel Corporation
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Since they ship libpqos and the binaries in one package but do not simultatious
# updates libversion can differ from binaries version.
%define libpqosMajor 6
%global make_flags EXTRA_CFLAGS="%{optflags}" SHARED=y PREFIX=%{buildroot}/%{_prefix} MAN_DIR=%{buildroot}/%{_mandir}/man8 LIB_INSTALL_DIR=%{buildroot}%{_libdir}/
Name:           intel-cmt-cat
Version:        24.05.12.git+c5f4492
Release:        1.1
Summary:        Command line interface to CMT, MBM, CAT and CDP technologies
License:        BSD-3-Clause
Group:          Development/Tools/Other
URL:            https://github.com/01org/%{name}
Source0:        %{name}-%{version}.tar.xz
#Source0:        https://github.com/intel/intel-cmt-cat/archive/v%%{version}.tar.gz#/%%{name}-%%{version}.tar.gz
Patch1:         fix-bad-env-shebang.patch
Patch2:         Remove-fcf-protection-full.patch
Patch3:         remove_gcc_check
BuildRequires:  doxygen
ExclusiveArch:  x86_64 %{ix86}

%description
This software package provides basic support for
Cache Monitoring Technology (CMT), Memory Bandwidth Monitoring (MBM),
Cache Allocation Technology (CAT) and Code Data Prioratization (CDP).

CMT, MBM and CAT are configured using Model Specific Registers (MSRs)
to measure last level cache occupancy, set up the class of service masks and
manage the association of the cores/logical threads to a class of service.
The software executes in user space, and access to the MSRs is
obtained through a standard Linux* interface. The virtual file system
provides an interface to read and write the MSR registers but
it requires root privileges.

%package     -n libpqos%{libpqosMajor}
Summary:        Runtime Platform Quality of Service library
Group:          System/Libraries

%description -n libpqos%{libpqosMajor}
PQoS library provides API to detect and configure Intel RDT including:
Cache Monitoring Technology (CMT), Memory Bandwidth Monitoring (MBM),
Cache Allocation Technology (CAT), Code and Data Prioritization (CDP) Technology.

%package     -n libpqos-devel
Summary:        Development package for libpqos%{libpqosMajor}
Group:          Development/Libraries/C and C++
Requires:       libpqos%{libpqosMajor} = %{version}
#Version number should stay constant here, because devel package had a version number in the name previously
Obsoletes:      libpqos1-devel < %{version}
Provides:       libpqos1-devel = %{version}

%description    -n libpqos-devel
PQoS library provides API to detect and configure Intel RDT including:
Cache Monitoring Technology (CMT), Memory Bandwidth Monitoring (MBM),
Cache Allocation Technology (CAT), Code and Data Prioritization (CDP) Technology.

This package contains all that is needed to develop/compile
applications that use PQoS.

%prep
%autosetup -p1

%build
%make_build %{make_flags}

%install
make %{make_flags} NOLDCONFIG=y install

%post -n libpqos%{libpqosMajor} -p /sbin/ldconfig
%postun -n libpqos%{libpqosMajor} -p /sbin/ldconfig

%files
%doc ChangeLog
%license LICENSE
%{_bindir}/membw
%{_mandir}/man8/membw.8%{?ext_man}
%{_bindir}/pqos
%{_mandir}/man8/pqos.8%{?ext_man}
%{_bindir}/rdtset
%{_mandir}/man8/rdtset.8%{?ext_man}
%{_bindir}/pqos-msr
%{_mandir}/man8/pqos-msr.8%{?ext_man}
%{_bindir}/pqos-os
%{_mandir}/man8/pqos-os.8%{?ext_man}

%files -n libpqos-devel
%{_includedir}/pqos.h
%{_libdir}/*.so

%files -n libpqos%{libpqosMajor}
%{_libdir}/*.so.*

%changelog
* Mon Oct 14 2024 trenn@suse.de
- Move to the new tag/version model, by using yy/mm in the version
  https://github.com/intel/intel-cmt-cat/issues/264
- Update to version 24.05.12.git+c5f4492:
  * lib: set errno when buf points to NULL in common.c:pqos_read()
  * lib: fix variable types in common.c:pqos_read()
  * llc capture time is increased in testcase test_pqos_cmt_llc_occupancy_cores
  * appqos_client: update 3rd party dependencies
  * appqos_client: update axios version
  * lib: Fix MBR value for non-SNC machines
  * tests: updated schema
  * tests: test_pqos_cmt_llc_occupancy_cores testcase is updated
  * After merging AMD SMBA feature, some unit tests are failed. They are fixed.
  * appqos_client: override dns-packet and socks package versions
  * appqos_client: update 'ws' and 'braces' depedency versions
  * appqos: pipenv 2024.0.1 can fetch pwr-v0.2.2. The word astroid is excluded in codespell.
  * Release 6.0.0
  * appqos: spelling correction
  * dependabot: exclude version updates
  * appqos_client: update required node and npm versions
  * dependabot: update config to ignore major version updates
  * appqos_client: update core-js to v3.23.3
  * appqos_client: update dev dependency versions
  * Add imediate binding flag to SWIG's Makefile
  * Add a GCC flag protecting againsh stack clash attacks
  * Enable strong stack protection for all the compilers
  * Add a stack protection flag to code examples
  * lib/cpuinfo: Increase the file descriptors limit to handle more CPUs
  * add dependabot config
  * Add warning message in case of detection hybrid architecture
  * lib: Fix parsing SMBA CLOS information
  * lib: Fix parsing MBA CLOS information
  * lib: Fix parsing L3 cache information
  * pqos tool hangs with wrong cores list format. That error is fixed.
  * appqos_client: update express dep version
  * AMD's SMBA is included in python wrapper
  * Skip some testcases in presence of SNC
  * Add SNC presence detection function for tests
  * appqos_client: update dependencies
  * rdtset: Update rdtset manpage to support SMBA feature
  * pqos: Update pqos manpage for SMBA feature
  * lib: Update cfg_set_cores_msr to support SMBA feature
  * rdtset: Update cfg_set_cores_os for SMBA feature
  * rdtset: Update cfg_set_pids to support SMBA feature
  * rdtset: Update cfg_configure_cos to support SMBA feature
  * rdtset: Update alloc_init and alloc_fini for SMBA feature
  * rdtset: Add the support for SMBA feature
  * rdtset: Update the rdt data structure to support SMBA feature
  * lib: Update the functions to reset the SMBA COS settings
  * pqos: Introduce _pqos_cap_smba_change
  * pqos: Update print_per_socket_config for SMBA
  * pqos: Introduce cap_print_features_smba
  * pqos: Update alloc_apply to support SMBA feature
  * pqos: Introduce set_smba_cos for SMBA
  * lib: Introduce os_smba_set_amd to update schemata for SMBA
  * lib: Add resctrl_schemata functions to support SMBA
  * lib: Introduce os_smba_get_amd to read the COS information
  * lib: Update resctrl_schemata functions to support SMBA
  * lib: Update the function resctrl_schemata_alloc to support SMBA feature
  * lib: Introduce resctrl_schemata_smba_get
  * lib: Introduce pqos_cpu_get_smba_ids
  * lib: Introduce data structures to support SMBA feature
  * lib: Implement the function hw_smba_set_amd
  * lib: Implement the function hw_smba_get_amd
  * lib: Introduce pqos_smba_get_cos_num
  * lib: Introduce pqos_cpu_get_one_by_smba_id
  * lib: Add Slow Memory Bandwidth Allocation MSR definition
  * lib: Discover SMBA feature using resctrl sysfs interface
  * lib: Discover SMBA feature using cpuid method
  * lib: Introduce Slow Memory Bandwidth Allocation
  * Add description of the memwb tool limitations
  M Remove-fcf-protection-full.patch
  Adopt patch to latest mainline changes
* Tue Mar 12 2024 trenn@suse.de
- Update to version 5.0.0.10.git+b26b31b:
  * Pinned-Dependencies are modified
  * appqos_client: update ip package version
  * appqos_client: update version to 1.1.1
  * Add compiler version checkings during build process
- Remove problematic fcf-protection gcc flag
  We currently build 32 bit flavors with -march=i586 where this
  compiler flag is not supported. Also some build envs still have gcc
  versions not supporting this feature. Unfortunately mainline seem not
  to be willing to remove the flag:
  https://github.com/intel/intel-cmt-cat/pull/267
  A Remove-fcf-protection-full.patch
- Remove gcc version check in general, if the tool is compiling it's expected
  to work, if extra flags unkown to the compiler are used the build will fail.
  A remove_gcc_check
* Mon Feb 12 2024 trenn@suse.de
- Update to version 5.0.6.git+14e3840:
  * rpm: add non-arch L3CAT detection patch
  * appqos_client: update follow-redirects version
  * workflows: update style check
  * License year update
  * The maintainer name is updated
  * appqos_client: update axios version
  * Release 5.0.0
  * The desc is freed in grp_free. So redundant free is removed.
  * Update hardware support section of the README
  * lib: update detection of non-architectural L3CAT
* Tue May 30 2023 Jan Engelhardt <jengelh@inai.de>
- Trim R/TM signs as per
  https://en.opensuse.org/openSUSE:Package_description_guidelines
* Fri Dec 23 2022 Dirk Müller <dmueller@suse.com>
- update to 4.4.1:
  * 1. General:
  - Bug fixes
- update to 4.4.0:
  * 1. Library:
  - Added LLC references monitoring event
  - Added uncore monitoring support
  * 2. PQoS
  - Added LLC references monitoring event
  - Added uncore monitoring support
  - Removed cpu topology limits
  * 3. App QoS
  - Added L2 CAT support
  * 4. General:
  - Added scan-build static analysis
  - Bug fixes
- update to 4.3.0:
  * 1. Library:
  - Added Elkhart Lake and Tiger Lake support
  - Improved CPU topology detection for OS interface
  - Automatic interface detection
  * 2. PQoS
  - Improved library interface selection
  * 3. rdtset
  - Improved library interface selection
  * 4. membw
  - Added membw to the package
  * 5. General:
  - Bug fixes
- update to 4.2.0:
  * 1. App QoS:
  - Added mTLS support
  - Extended capability information
  * Support for running AppQoS in docker container
  * 2. General:
- update to 4.1.0:
  * 1. AppQoS:
  - Added OS interface support
  - Added MBA CTRL support
  * 2. PQoS:
  - Added option to display PQoS tool version
  * 3. General:
  - Bug fixes
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 4.0.0:
  - Use perf for IPC and cache misses monitoring with MSR interface
  - Detection of MBA2.0 and MBA3.0
  - 32b MBM counters support
  - AMD support
  - Added ansible scripts
  - Added option to display MBT column in monitoring output
  - Added option to disable IPC monitoring
  - Added option to disable cache misses monitoring
  - Added support for Power Profiles
  - Bug fixes
* Wed Aug 21 2019 Christian Vögl <christian.voegl@suse.com>
- Updated to version 3.1
  From Mainline Changelog:
    1. Library:
  - Added Python wrapper for the library
    2. PQoS Utility:
  - Output LLC occupancy in percent
    3. rdtset Utility:
  - Added support for multiple instances
    4. AppQoS:
  - Added new sample application
    5. examples:
  - Added examples for python library
    6. tests:
  - Added basic functional tests
    7. General
  - Bug fixes
* Thu Mar 28 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Thu Mar 28 2019 Christian Vögl <christian.voegl@suse.com>
- Updated git url to new location
- Updated to version 3.0.1:
  From mainline Changelog:
  3.0.1:
  1. General
  - Bug fixes
  3.0.0:
  1. Library
  - Added support for Resctrl MBA software controller
  - Improved detection of OS (Resctrl) capabilities
  2. PQoS Utility
  - Added support for Resctrl MBA software controller
  - Updated feature enumeration to show capabilities for selected
    interface only
  3. rdtset Utility
  - Added support for Resctrl MBA software controller
  4. membw
  - Added support for extra memory operations
  - Improved accuracy
  5.General
  - Bug fixes
  2.1.0:
  1.Library
  - Reversed RMID allocation
  2.rdtset Utility
  - Added support for MSR based MBA software controller
  3.Examples
  - Added MBA example application
  - Added L2CAT example application
  4.membw
  - Added tool for generation of memory bandwidth
  5.General
  - Bug fixes
* Fri Sep 14 2018 trenn@suse.de
- libpqos-devel must obsolete libpqos1-devel since last change
* Tue Sep 11 2018 trenn@suse.de
- Rename libpqos2-devel to libpqos-devel.
  Library devel package must not include library version in name
* Tue Sep  4 2018 trenn@suse.de
- Update to version 2.0.0
  Bump up libpqos1 package version to libpqos2
- Remove ldconfig patch and use NOLDCONFIG Makefile variable
  D    fix-ldconfig-call.patch
- Do not use env in shebang to avoid osc errors:
  A    fix-bad-env-shebang.patch
  From mainline Changelog:
  1. Library
  - Added support for resctrl monitoring via OS interface
  - Added support for PID group monitoring
  - Added support for L2 CDP
  - New API added for adding/removing pids to mon groups
  2. PQoS Utility
  - Added support for PID group monitoring
  - Added support for L2 CDP
  - Print core values in PID monitoring output
  3. rdtset Utility
  - Added support for L2 CDP
* Thu Mar  1 2018 trenn@suse.de
- Update to version 1.1.0 (fate#322856):
  1. Library
  - Added support for MBA configuration via OS interface
  2. PQoS Utility
  - Added better feature enumeration functionality
  - Added top-pids monitoring functionality
- Change group declaration in spec file from
  Development/Tools
  to
  Development/Tools/Other
  to avoid invalid group build service warning.
- Adding _service file for easier version upgrades
  Replacing the libversion variable in spec file with the real
  version, so that automated version upgrades via service feature
  works.
* Fri Aug  4 2017 trenn@suse.de
- Update to version 1.1.0 (fate#322856):
  1. Library
  - Added PID support for L2CAT, L3CAT and CDP
  - Added global RDT interface enforcement.
  2. PQoS Utility
  - Added PID support for L2CAT, L3CAT and CDP
  3. rdtset Utility
  - Added PID support for L2CAT, L3CAT and CDP
  - Updated to work with multiple PID's
  D    fix-dynlib-generation.patch
  D    fixsymlink.patch
* Thu Jul 13 2017 bwiedemann@suse.com
- Update to version 1.0.1:
    snmp
  - Added OS interface support to Net-SNMP sub-agent
    General
  - Build improvements (boo#1041090)
  - Bug fixes
    Library
  - Removed NO_PID_API compile time option
  - Added OS interface to support L3/L2 CAT & CDP
  - Updated support for CMT per PID
    PQoS Utility
  - Added pqos-os & pqos-msr wrapper scripts
  - Added option to select OS or MSR interface
    rdtset Utility
  - Added option to select OS or MSR interface
    Examples
  - Support for new OS/MSR interface added to CMT/MBM examples
- Add fixsymlink.patch to create proper man page symlinks
- Rebase fix-dynlib-generation.patch
* Tue Mar  7 2017 fschnizlein@suse.de
- Fixes bsc#990230 (if submitted and accepted in factory)
- Renamed intel-cmt-cat-devel to libqpos0-devel
- Removed obsolete patches due Makefile restructuring
  D intel-cmt-cat-DESTDIR.patch
  D intel-cmt-cat-Makefile.patch
  D intel-cmt-cat-dynlib.patch
- Added patches to build library correctly
  A fix-dynlib-generation.patch
  A fix-ldconfig-call.patch
- Added _service file
- Update to version 0.1.5-1:
  * Added MBA get to library.
  * MBA added to pqos tool show configuration option
  * Added mba -e option to pqos
  * MBA added to allocation reset function
  * Updated changelog, pqos help menu and man page with L2 CAT per cluster and MBA changes.
  * Added 11 LLC ways configuration files for pqos
  * Added profile with 11 cache ways
  * Corrected detection of MBM capabilities
  * Updated pqos utility error message for when no allocation resource ID is specified.
  * Modified pqos_pid_start API to only set single bit in event mask when starting remote memory B/W monitoring using perf. Moved remote memory monitor dependences to RMEM section.
* Thu Dec  1 2016 trenn@suse.de
- Initial package
- split off -devel and lib package.
- Patches added:
  * Makefile_include.patch
  * Makefile_ldconfig.patch
